A free audio dataset of spoken digits. Think MNIST for audio.

A simple audio/speech dataset consisting of recordings of spoken digits in wav
files at 8kHz.
The recordings are trimmed so that they have near minimal silence at the
beginnings and ends.

5 speakers\
2,500 recordings (50 of each digit per speaker)\
English pronunciations

Files are named in the following format: {digitLabel}_{speakerName}_{index}.wav